# This file is part of the sos project: https://github.com/sosreport/sos
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# version 2 of the GNU General Public License.
#
# See the LICENSE file in the source distribution for further information.

from sos.report.plugins import Plugin, DebianPlugin


class AstraSosreportPlugin(Plugin, DebianPlugin):
    """Astra Linux system plugin
    """
    short_desc = "Astra Linux system plugin"
    plugin_name = "astra-sosreport"
    profiles = ('system', 'services')

    #packages = ('astra-sosreport',)

    def setup(self):
        self.add_cmd_output([
            "passwd -Sa",
            "lsinput",
            "lspci -knn",
            "dmesg -T",
            "usb-devices",
            "netstat -tulpn",
            "smbtree -N",
            "testparm -vs",
            "df -h",
            "df -i",
            "astra-event-diagnostics -v",
        ])

        self.add_forbidden_path("/etc/ssl/")
        self.add_forbidden_path("/etc/ssl/certs")
        self.add_forbidden_path("/etc/ssl/private")
        #lastlog output will be collected in the "login" module
        self.add_forbidden_path("/var/log/lastlog")
        self.add_forbidden_path("/var/log/faillog")

        if self.get_option("all_logs"):
            self.add_copy_spec(["/parsec/log/astra/events*", "/var/log"])
            self.add_cmd_output([
            "faillog",
            "faillog -u 0-999",
            "faillog -u 1000-60000",
            "faillog -u 60001-65536",
            "faillog -u 65537-4294967295",
        ])
        else:
            self.add_copy_spec("/parsec/log/astra/events")
        self.add_copy_spec([    
            "/home/.xsession-errors*",
            "/home/*/.xsession-errors*",
            "/home/*/*/.xsession-errors*",
            "/home/.xorgxrdp.*.log",
            "/home/*/.xorgxrdp.*.log",
            "/home/*/*/.xorgxrdp.*.log",
            "/usr/share/X11/xorg.conf.d",
            "/var/lib/systemd/coredump",
            "/var/log/fly-dm",
            "/var/log/auth.log",
            "/etc"
       ], sizelimit=5000)  

    def postproc(self):
        self.do_path_regex_sub(
            r".*\.pem",
            r".*",
            r""
        )
        self.do_path_regex_sub(
            r".*\.key",
            r".*",
            r""
        )
        self.do_path_regex_sub(
            r".*shadow.*",
            r".*",
            r""
        )
        self.do_path_regex_sub(
            r".*ssh_.*_key",
            r".*",
            r""
        )
        self.do_path_regex_sub(
            r".*\/etc\/ssl\/private\/.*",
            r".*",
            r""
        )

# vim: set et ts=4 sw=4 :
