# This file is part of the sos project: https://github.com/sosreport/sos
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# version 2 of the GNU General Public License.
#
# See the LICENSE file in the source distribution for further information.

from sos.report.plugins import Plugin, DebianPlugin


class CryptoproPlugin(Plugin, DebianPlugin):
    """CryptoPro CSP debug info collector
       borrowed from cprodiag script:
       https://cryptopro.ru/sites/default/files/products/csp/cprodiag
    """
    short_desc = "CryptoPro CSP debug info collector"
    plugin_name = "cryptopro"
    profiles = ('csp',)

    def setup(self):

        self.add_cmd_output([
            "/opt/cprocsp/bin/amd64/cptestf -defprov -enum_type",
            "/opt/cprocsp/bin/amd64/cptestf -defprov -enum -provtype -1",
            "/opt/cprocsp/bin/amd64/cptestf -defprov -enum -provtype 75",
            "/opt/cprocsp/bin/amd64/cptestf -defprov -enum -provtype 80",
            "/opt/cprocsp/bin/amd64/cptestf -defprov -enum -provtype 81",
            "/opt/cprocsp/bin/amd64/cptest -keyset -verifycontext -provtype 75",
            "/opt/cprocsp/bin/amd64/cptest -keyset -verifycontext -provtype 80",
            "/opt/cprocsp/bin/amd64/cptest -keyset -verifycontext -provtype 81",
            "/opt/cprocsp/bin/amd64/cptest -card -enum -verbose -verbose",
            "/opt/cprocsp/bin/amd64/cptest -enum -info -type PP_ENUMREADERS -flags 32",
            "/opt/cprocsp/bin/amd64/cptest -keyset -verifycontext -enum -fqcn",
            "/opt/cprocsp/bin/amd64/cptest -keyset -verifycontext -enum -unique",
            "/opt/cprocsp/bin/amd64/certmgr -list -store umy",
            "/opt/cprocsp/bin/amd64/certmgr -list -store mmy",
            "/opt/cprocsp/bin/amd64/certmgr -list -store mroot",
            "/opt/cprocsp/bin/amd64/certmgr -list -store mca",
            "/opt/cprocsp/bin/amd64/certmgr -list -store mca -crl"
        ])

        containers = self.exec_cmd('/opt/cprocsp/bin/amd64/csptest -keyset -verifycontext -enum -unique')
        if containers['status'] == 0:
            conts_lines = containers['output'].splitlines()
            for container in conts_lines:
                if "|" in container:
                    full_line = container.split("|")
                    if len(full_line) > 1:
                        cont_name = full_line[1]
                        self.add_cmd_output("/opt/cprocsp/bin/amd64/csptest -keyset -silent -info -fqcn -container '%s' " % (cont_name))
                        self.add_cmd_output("/opt/cprocsp/bin/amd64/csptest -keyset -silent -check -fqcn -container '%s' " % (cont_name))
                        
        self.add_copy_spec([    
            "/etc/opt/cprocsp",
            "/opt/cprocsp/lib/hashes",
            "/var/opt/cprocsp/users*",
            "/etc/init.d/cprocsp"
       ], sizelimit=5000)  

# vim: set et ts=4 sw=4 :
